@@ -140,8 +140,8 @@ class CORS(base.ConfigurableMiddleware):
         allow_methods: List of HTTP methods to permit.
         allow_headers: List of HTTP headers to permit from the client.
         """
-        if ('allowed_origin' not in local_conf
-           and 'oslo_config_project' not in local_conf):
+        if ('allowed_origin' not in local_conf and
+           'oslo_config_project' not in local_conf):
             raise TypeError("allowed_origin or oslo_config_project "
                             "is required")
         return super(CORS, cls).factory(global_conf, **local_conf)
@@ -210,7 +210,7 @@ class CORS(base.ConfigurableMiddleware):
         # NOTE(dims): Support older code that still passes in
         # a string for allowed_origin instead of a list
         if isinstance(allowed_origin, six.string_types):
-            # TODO(krotscheck): https://review.openstack.org/#/c/312687/
+            # TODO(krotscheck): https://review.opendev.org/#/c/312687/
             LOG.warning('DEPRECATED: The `allowed_origin` keyword argument in '
                         '`add_origin()` should be a list, found String.')
             allowed_origin = [allowed_origin]
